@@ -11,7 +11,7 @@ import (
 	"strings"
 	"unicode/utf8"
 
-	"arp242.net/uni/v2/unidata"
+	"zgo.at/uni/v2/unidata"
 	"zgo.at/zli"
 	"zgo.at/zstd/zstring"
 )
@@ -36,7 +36,7 @@ Flags:
     -j, -json      Output as JSON.
 
 Commands:
-    identify       Identity all the characters in the given strings.
+    identify       Identify all the characters in the given strings.
     search         Search description for any of the words.
     print          Print characters by codepoint, category, or block.
     emoji          Search emojis.
@@ -67,7 +67,7 @@ Flags:
                    columns.
 
 Commands:
-    identify [text]  Idenfity all the characters in the given strings.
+    identify [text]  Identify all the characters in the given strings.
 
     search [query]   Search description for any of the words.
 
@@ -149,6 +149,8 @@ Format:
         %(name r:5)     Right-align and pad with 5 spaces
         %(name q)       Quote with single quotes, excluding any padding
         %(name t)       Trim this column if it's longer than the screen width
+        %(name f:C)     Fill this column with character C; especially useful for
+                        numbers: %(bin r:auto f:0)
 
     Placeholders that work for all commands:
         %(tab)           A literal tab when outputting to a terminal, or four
@@ -160,6 +162,8 @@ Format:
         %(char)          The literal character          ✓
         %(cpoint)        As codepoint                   U+2713
         %(hex)           As hex                         2713
+        %(oct)           As octal                       23423
+        %(bin)           As binary (little-endian)      10011100010011
         %(dec)           As decimal                     10003
         %(utf8)          As UTF-8                       e2 9c 93
         %(utf16le)       As UTF-16 LE (Windows)         13 27
@@ -178,7 +182,7 @@ Format:
                          space otherwise; for alignment
 
         The default is:
-        %(char q l:3)%(wide_padding) %(cpoint l:7) %(dec l:6) %(utf8 l:11) %(html l:10) %(name t) (%(cat t))
+        `+defaultFormat+`
 
     Placeholders for emoji:
 
@@ -191,9 +195,20 @@ Format:
         %(cldr_full)   Full CLDR data                   firefighter, firetruck
 
         The default is:
-        %(emoji)%(tab)%(name l:auto)  (%(cldr t))
+        `+defaultEmojiFormat+`
 `)
 
+const (
+	defaultFormat = "%(char q l:3)%(wide_padding) %(cpoint l:7) %(dec l:6) %(utf8 l:11) %(html l:10) %(name t) (%(cat t))"
+	allFormat     = "%(char q l:3)%(wide_padding) %(cpoint l:auto) %(width l:auto) %(dec l:auto) %(hex l:auto)" +
+		" %(oct l:auto) %(bin l:auto)" +
+		" %(utf8 l:auto) %(utf16le l:auto) %(utf16be l:auto) %(html l:auto) %(xml l:auto) %(json l:auto)" +
+		" %(keysym l:auto) %(digraph l:auto) %(name l:auto) %(plane l:auto) %(cat l:auto) %(block l:auto)"
+
+	defaultEmojiFormat = "%(emoji)%(tab)%(name l:auto)  (%(cldr t))"
+	allEmojiFormat     = "%(emoji)%(tab)%(name l:auto) %(group l:auto) %(subgroup l:auto) %(cpoint l:auto) %(cldr l:auto) %(cldr_full)"
+)
+
 func main() {
 	flag := zli.NewFlags(os.Args)
 	var (
@@ -249,17 +264,16 @@ func main() {
 
 	format := formatF.String()
 	if !formatF.Set() {
-		format = "%(char q l:3)%(wide_padding) %(cpoint l:7) %(dec l:6) %(utf8 l:11) %(html l:10) %(name t) (%(cat t))"
+		format = defaultFormat
 		if cmd == "emoji" {
-			format = "%(emoji)%(tab)%(name l:auto)  (%(cldr t))"
+			format = defaultEmojiFormat
 		}
 	}
+
 	if formatF.String() == "all" {
-		format = "%(char q l:3)%(wide_padding) %(cpoint l:auto) %(width l:auto) %(dec l:auto) %(hex l:auto)" +
-			" %(utf8 l:auto) %(utf16le l:auto) %(utf16be l:auto) %(html l:auto) %(xml l:auto) %(json l:auto)" +
-			" %(keysym l:auto) %(digraph l:auto) %(name l:auto) %(plane l:auto) %(cat l:auto) %(block l:auto)"
+		format = allFormat
 		if cmd == "emoji" {
-			format = "%(emoji)%(tab)%(name l:auto) %(group l:auto) %(subgroup l:auto) %(cpoint l:auto) %(cldr l:auto) %(cldr_full)"
+			format = allEmojiFormat
 		}
 	}
 
@@ -490,19 +504,6 @@ func print(args []string, format string, quiet, raw, asJSON bool) error {
 			s = []string{canon, canon}
 		}
 
-		// ToRune interperts "40" as base 16; add 0d for decimals.
-		if strings.HasPrefix(strings.ToUpper(s[0]), "0D") {
-			// Let ToRune deal with any errors.
-			if n, err := strconv.ParseInt(s[0][2:], 10, 10); err == nil {
-				s[0] = strconv.FormatInt(n, 16)
-			}
-		}
-		if strings.HasPrefix(strings.ToUpper(s[1]), "0D") {
-			if n, err := strconv.ParseInt(s[1][2:], 10, 10); err == nil {
-				s[1] = strconv.FormatInt(n, 16)
-			}
-		}
-
 		start, err := unidata.ToRune(s[0])
 		if err != nil {
 			return fmt.Errorf("invalid codepoint: %s", err)
